from Screens.Screen import Screen
from Screens.LocationBox import TimerLocationBox, InstantrecordLocationBox, TimeshiftLocationBox
from Components.Label import Label
from Components.config import config, ConfigSelection, getConfigListEntry
from Components.ConfigList import ConfigListScreen
from Components.ActionMap import ActionMap
from Components.Button import Button

class RecordPathsSettings(Screen, ConfigListScreen):
	skin = """
		<screen name="RecordPathsSettings" position="160,150" size="450,200" title="Record paths">
			<ePixmap pixmap="skin_default/buttons/red.png" position="10,0" size="140,40" alphatest="on" />
			<ePixmap pixmap="skin_default/buttons/green.png" position="300,0" size="140,40" alphatest="on" />
			<widget name="key_red" position="10,0" zPosition="1" size="140,40" font="Regular;20" halign="center" valign="center" backgroundColor="#9f1313" transparent="1" />
			<widget name="key_green" position="300,0" zPosition="1" size="140,40" font="Regular;20" halign="center" valign="center" backgroundColor="#1f771f" transparent="1" />
			<widget name="config" position="10,44" size="430,146" />
		</screen>"""

	def __init__(self, session):
		Screen.__init__(self, session)

		self["key_red"] = Button(_("Cancel"))
		self["key_green"] = Button(_("Save"))

		ConfigListScreen.__init__(self, [])

		default = config.usage.timer_record_path.value
		tmp = config.movielist.videodirs.value
		if default not in tmp:
			tmp.append(default)
		self.timer_record_dirname = ConfigSelection(default = default, choices = tmp)
		default = config.usage.instantrecord_path.value
		if default not in tmp:
			tmp.append(default)
		self.instantrecord_dirname = ConfigSelection(default = default, choices = tmp)
		default = config.usage.timeshift_path.value
		tmp = config.usage.allowed_timeshift_paths.value
		if default not in tmp:
			tmp.append(default)
		self.timeshift_dirname = ConfigSelection(default = default, choices = tmp)

		self.timer_record_path = getConfigListEntry(_("Timer record path"), self.timer_record_dirname)
		self.instantrecord_path = getConfigListEntry(_("Instant record path"), self.instantrecord_dirname)
		self.timeshift_path = getConfigListEntry(_("Timeshift path"), self.timeshift_dirname)
		self.list = []
		self.list.append(self.timer_record_path)
		self.list.append(self.instantrecord_path)
		self.list.append(self.timeshift_path)
		self["config"].setList(self.list)

		self["setupActions"] = ActionMap(["OkCancelActions", "ColorActions"],
		{
			"green": self.save,
			"red": self.cancel,
			"cancel": self.cancel,
			"ok": self.ok,
		}, -2)

	def ok(self):
		cur = self["config"].getCurrent()
		if cur == self.timer_record_path:
			self.session.openWithCallback(
				self.timerPathSelected,
				TimerLocationBox,
				self.timer_record_dirname.value,
			)
		elif cur == self.instantrecord_path:
			self.session.openWithCallback(
				self.instantrecordPathSelected,
				InstantrecordLocationBox,
				self.instantrecord_dirname.value,
			)
		elif cur == self.timeshift_path:
			self.session.openWithCallback(
				self.timeshiftPathSelected,
				TimeshiftLocationBox,
				self.timeshift_dirname.value,
			)

	def timerPathSelected(self, res):
		if res:
			if config.movielist.videodirs.value != self.timer_record_dirname.choices:
				self.timer_record_dirname.setChoices(config.movielist.videodirs.value, default=res)
			self.timer_record_dirname.value = res

	def instantrecordPathSelected(self, res):
		if res:
			if config.movielist.videodirs.value != self.instantrecord_dirname.choices:
				self.instantrecord_dirname.setChoices(config.movielist.videodirs.value, default=res)
			self.instantrecord_dirname.value = res

	def timeshiftPathSelected(self, res):
		if res:
			if config.usage.allowed_timeshift_paths.value != self.timeshift_dirname.choices:
				self.timeshift_dirname.setChoices(config.usage.allowed_timeshift_paths.value, default=res)
			self.timeshift_dirname.value = res

	def save(self):
		config.usage.timer_record_path.value = self.timer_record_dirname.value
		config.usage.instantrecord_path.value = self.instantrecord_dirname.value
		config.usage.timeshift_path.value = self.timeshift_dirname.value
		config.usage.timer_record_path.save()
		config.usage.instantrecord_path.save()
		config.usage.timeshift_path.save()
		self.close()

	def cancel(self):
		self.close()
